@@ -1326,17 +1326,21 @@ class gdaAttack:
         except requests.ConnectionError as e:
             print("Connection Error. Make sure you are connected to Internet.")
             print(str(e))
+            reply = dict(error=str(e))
 
         except requests.Timeout as e:
             print("Timeout Error")
             print(str(e))
+            reply = dict(error=str(e))
 
         except requests.RequestException as e:
             print("General Error")
             print(str(e))
+            reply = dict(error=str(e))
 
         except KeyboardInterrupt:
             print("Program closed")
+            reply = dict(error="Program closed")
 
 
         reply['query'] = query
